"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeError = exports.handleTelegramResponse = exports.TelegramError = exports.TeleBotError = exports.ERROR_TELEBOT_MAXIMUM_RETRY = exports.ERROR_TELEBOT_ALREADY_RUNNING = void 0;
exports.ERROR_TELEBOT_ALREADY_RUNNING = "Telebot is already running. Terminate instance for safety.";
exports.ERROR_TELEBOT_MAXIMUM_RETRY = "Maximum retries exceeded. Terminate instance for safety.";
class TeleBotError extends Error {
    constructor(message, payload) {
        super(message);
        this.name = "TeleBotError";
        this.payload = payload;
    }
}
exports.TeleBotError = TeleBotError;
class TelegramError extends Error {
    constructor(response) {
        super(`${response.status} - ${response.statusText}`);
        this.name = "TelegramError";
        const { url, method, data } = response.config;
        this.request = { url, method, data };
        this.response = response.data;
    }
}
exports.TelegramError = TelegramError;
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function handleTelegramResponse(error) {
    if (error.isAxiosError) {
        const { response } = error;
        if (response) {
            return new TelegramError(response);
        }
    }
    return error;
}
exports.handleTelegramResponse = handleTelegramResponse;
function normalizeError(error, payload) {
    if (!(error instanceof Error)) {
        error = new TeleBotError(error);
    }
    if (payload) {
        error.payload = payload;
    }
    return error;
}
exports.normalizeError = normalizeError;
