/// <reference types="node" />
import { PathLike, ReadStream } from "fs";
import { TeleBotEventContext, TeleBotEventName, TeleBotEventPayload, TeleBotEventProcessor, TeleBotFlags, TeleBotHearsName, TeleBotHearsPayload, TeleBotHearsProcessor, TeleBotMethodName, TeleBotModifierContext, TeleBotModifierName, TeleBotModifierPayload, TeleBotModifierProcessor, TeleBotOptions, TeleBotPlugin, TeleBotPluginContext, TeleBotPolling } from "./types/telebot";
import { TelegramBotToken, Update, User } from "./types/telegram";
import { TeleBotLogger, TeleBotLogOptions } from "./telebot/logger";
export declare const DEFAULT_POLLING: TeleBotPolling;
export declare const DEFAULT_DEBUG: TeleBotLogOptions;
export declare class TeleBot {
    private readonly botAPI;
    private readonly botToken;
    private polling;
    private readonly webhook?;
    private readonly proxy?;
    private lifeIntervalFn;
    private readonly allowedUpdates?;
    private readonly debug;
    private flags;
    me?: User;
    logger: TeleBotLogger;
    private events;
    private hearsEvents;
    private modifiers;
    private plugins;
    constructor(options: TeleBotOptions | TelegramBotToken);
    getToken(): TelegramBotToken;
    getOptions(): Omit<TeleBotOptions, "botAPI"> & {
        botAPI: string;
    };
    start(): Promise<void>;
    restart(): Promise<unknown>;
    stop(): Promise<void>;
    getFlags(): TeleBotFlags;
    hasFlag<T extends keyof TeleBotFlags>(name: T): boolean;
    setFlag<T extends keyof TeleBotFlags>(name: T): void;
    unsetFlag<T extends keyof TeleBotFlags>(name: T): void;
    private setOffset;
    private startLifeCycle;
    private startLifeInterval;
    private lifeCycle;
    private fetchTelegramUpdates;
    processTelegramUpdates(updates: Update[]): Promise<unknown>;
    telegramRequest<Request = Record<string, unknown>, Response = Record<string, unknown>>(endpoint: string, payload: Request): Promise<Response>;
    telegramMethod<T>({ method, required, optional, isDataForm }: {
        method: TeleBotMethodName;
        required?: Record<string, any>;
        optional?: Record<string, any>;
        isDataForm?: boolean;
    }): Promise<T>;
    uploadFile(path: PathLike): ReadStream;
    parallel<T = unknown>(tasks: Promise<T>[]): Promise<T[]>;
    plugin<T extends TeleBotPluginContext>(plugin: TeleBotPlugin<T>, context: T): void;
    hears<T extends TeleBotHearsName>(text: T | T[], processor: TeleBotHearsProcessor<T>): void;
    dispatchHears(text: string, payload: TeleBotHearsPayload): Promise<unknown[]>;
    mod<T extends TeleBotModifierName>(name: T, processor: TeleBotModifierProcessor<T>): void;
    run<T extends TeleBotModifierName, P = TeleBotModifierPayload>(event: T, payload: P, context?: TeleBotModifierContext): Promise<P>;
    on<T extends TeleBotEventName>(event: T | T[], processor: TeleBotEventProcessor<T>): void;
    dispatch<T extends TeleBotEventName, P = TeleBotEventPayload<T>>(event: T | T[], payload?: P, context?: TeleBotEventContext): Promise<unknown>;
}
