"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TeleBotLogger = exports.Levels = exports.LID = void 0;
const utils_1 = require("../utils");
exports.LID = {
    Initial: "Initial",
    TeleBot: "TeleBot",
    Tick: "Tick",
    Pass: "Pass",
    Stop: "Stop",
    Restart: "Restart",
    SetFlag: "SetFlag",
    UnsetFlag: "UnsetFlag",
    SetOffset: "SetOffset",
    StartLifeCycle: "StartLifeCycle",
    StartLifeInterval: "StartLifeInterval",
    LiveInterval: "LiveInterval",
    LifeCycle: "LifeCycle",
    FetchTelegramUpdates: "FetchTelegramUpdates",
    ProcessTelegramUpdates: "ProcessTelegramUpdates",
    TelegramRequest: "TelegramRequest",
    TelegramMethod: "TelegramMethod",
    Plugin: "Plugin",
    Event: "Event",
    Modifier: "Modifier",
    Dispatch: "Dispatch",
    Hears: "Hears",
    DispatchHears: "DispatchHears",
    Webhook: "Webhook",
    Error: "Error"
};
var Levels;
(function (Levels) {
    Levels["error"] = "error";
    Levels["warn"] = "warn";
    Levels["log"] = "log";
    Levels["http"] = "http";
    Levels["info"] = "info";
    Levels["debug"] = "debug";
})(Levels = exports.Levels || (exports.Levels = {}));
class TeleBotLogger {
    constructor(id, options) {
        this.error = this.createProcessor(Levels.error);
        this.warn = this.createProcessor(Levels.warn);
        this.http = this.createProcessor(Levels.http);
        this.log = this.createProcessor(Levels.log);
        this.info = this.createProcessor(Levels.info);
        this.debug = this.createProcessor(Levels.debug);
        this.id = id;
        this.options = options;
    }
    logger(log) {
        var _a;
        if (!this.options) {
            return;
        }
        const { id, code, level = Levels.debug, meta, message, error } = log;
        const { ids, levels } = this.options;
        if ((ids && !ids.includes(id)) || (levels && !levels.includes(level))) {
            return;
        }
        if ((_a = this.options) === null || _a === void 0 ? void 0 : _a.logger) {
            return this.options.logger.call(this, log);
        }
        const t = new Date();
        const logId = [id, code].filter(i => !!i && i !== 0).join(":");
        const text = [message || utils_1.toString(meta), error].filter(i => !!i).join(" ");
        // eslint-disable-next-line no-console
        console.log(`[${t.toLocaleString("en-GB")}] ${level}: ${logId} ${text}`);
    }
    createProcessor(level) {
        return (id, props) => {
            if (typeof props === "string") {
                props = { message: props };
            }
            else if (props === null || props === void 0 ? void 0 : props.meta) {
                props.message = utils_1.toString(props === null || props === void 0 ? void 0 : props.meta);
            }
            this.logger(Object.assign(Object.assign({}, props), { id,
                level }));
        };
    }
}
exports.TeleBotLogger = TeleBotLogger;
