"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TELEGRAM_UPDATE_PROCESSORS = void 0;
const MESSAGE_TYPES = [
    "text",
    "audio",
    "document",
    "animation",
    "game",
    "photo",
    "sticker",
    "video",
    "video_note",
    "voice",
    "caption",
    "contact",
    "location",
    "venue",
    "poll",
    "dice",
    "new_chat_members",
    "left_chat_member",
    "new_chat_title",
    "new_chat_photo",
    "delete_chat_photo",
    "group_chat_created",
    "supergroup_chat_created",
    "channel_chat_created",
    "message_auto_delete_timer_changed",
    "migrate_to_chat_id",
    "migrate_from_chat_id",
    "pinned_message",
    "invoice",
    "successful_payment",
    "connected_website",
    "passport_data",
    "proximity_alert_triggered",
    "voice_chat_started",
    "voice_chat_ended",
    "voice_chat_participants_invited"
];
exports.TELEGRAM_UPDATE_PROCESSORS = {
    edited_message(messageUpdate, context) {
        return this.dispatch("edited_message", messageUpdate, context);
    },
    channel_post(messageUpdate, context) {
        return this.dispatch("channel_post", messageUpdate, context);
    },
    edited_channel_post(messageUpdate, context) {
        return this.dispatch("edited_channel_post", messageUpdate, context);
    },
    inline_query(inlineQueryUpdate, context) {
        return this.dispatch("inline_query", inlineQueryUpdate, context);
    },
    chosen_inline_result(chosenInlineUpdate, context) {
        return this.dispatch("chosen_inline_result", chosenInlineUpdate, context);
    },
    callback_query(callbackQueryUpdate, context) {
        return this.dispatch("callback_query", callbackQueryUpdate, context);
    },
    shipping_query(shippingQueryUpdate, context) {
        return this.dispatch("shipping_query", shippingQueryUpdate, context);
    },
    pre_checkout_query(preCheckoutQueryUpdate, context) {
        return this.dispatch("pre_checkout_query", preCheckoutQueryUpdate, context);
    },
    poll(pollUpdate, context) {
        return this.dispatch("poll", pollUpdate, context);
    },
    poll_answer(pollAnswerUpdate, context) {
        return this.dispatch("poll_answer", pollAnswerUpdate, context);
    },
    my_chat_member(myChatMember, context) {
        return this.dispatch("my_chat_member", myChatMember, context);
    },
    chat_member(chatMember, context) {
        return this.dispatch("chat_member", chatMember, context);
    },
    message(messageUpdate, context) {
        return __awaiter(this, void 0, void 0, function* () {
            const processorPromises = [];
            processorPromises.push(this.dispatch("message", messageUpdate, context));
            for (const messageType of MESSAGE_TYPES) {
                if (messageType in messageUpdate) {
                    const modifiedMessageUpdate = yield this.run(messageType, Object.assign({}, messageUpdate));
                    processorPromises.push(this.dispatch(messageType, modifiedMessageUpdate, context));
                    if (messageType === "text") {
                        processorPromises.push(this.dispatchHears(messageUpdate.text, modifiedMessageUpdate));
                    }
                    break;
                }
            }
            return Promise.resolve(Promise.all(processorPromises));
        });
    }
};
